@@ -11,6 +11,9 @@
 #undef HAVE_INET_ATON
 #undef ORBIT_SERIAL
 
+/* Define to 'int' if it isn't defined in the header files. */
+#undef socklen_t
+
 #undef  ALIGNOF_CORBA_BOOLEAN
 #undef  ALIGNOF_CORBA_CHAR
 #undef  ALIGNOF_CORBA_DOUBLE
@@ -30,3 +33,7 @@
 /* TCP wrappers */
 #undef HAVE_HOSTS_ACCESS
 #undef HAVE_TCPD_H
+
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
