@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.c,v 1.103 1999/03/25 09:08:32 andrewtv Exp $
+    $Id: util.c,v 1.106 1999/04/02 00:52:29 andrewtv Exp $
 
 ***************************************************************************/
 #include <assert.h>
@@ -185,7 +185,8 @@ static void IDL_tree_optimize (IDL_tree *p, IDL_ns ns)
 {
 	if (!(__IDL_flags & IDLF_IGNORE_FORWARDS))
 		IDL_tree_process_forward_dcls (p, ns);
-	IDL_tree_remove_inhibits (p, ns);
+	if (!(__IDL_flags & IDLF_INHIBIT_TAG_ONLY))
+		IDL_tree_remove_inhibits (p, ns);
 	IDL_tree_remove_empty_modules (p, ns);
 }
 
@@ -748,7 +749,7 @@ int IDL_tree_get_node_info (IDL_tree p, char **what, char **who)
 	case IDLN_PARAM_DCL:
 		*what = "operation parameter";
 		assert (IDL_PARAM_DCL (p).simple_declarator != NULL);
-		assert (IDL_NODE_TYPE (IDL_PARAM_DCL (p).simple_declarator) = IDLN_IDENT);
+		assert (IDL_NODE_TYPE (IDL_PARAM_DCL (p).simple_declarator) == IDLN_IDENT);
 		*who = IDL_IDENT (IDL_PARAM_DCL (p).simple_declarator).str;
 		break;
 
@@ -2278,7 +2279,6 @@ static int load_inhibits (IDL_tree_func_data *tfd, GHashTable *table)
 	    IDL_NODE_TYPE (IDL_NODE_UP (p)) == IDLN_LIST &&
 	    IDL_NODE_DECLSPEC (p) & IDLF_DECLSPEC_INHIBIT &&
 	    !g_hash_table_lookup_extended (table, IDL_NODE_UP (p), NULL, NULL)) {
-
 		list_head = NULL;
 		q = IDL_NODE_UP (IDL_NODE_UP (p));
 		if (q) {
@@ -2298,20 +2298,25 @@ static int load_inhibits (IDL_tree_func_data *tfd, GHashTable *table)
 			}
 		}
 		g_hash_table_insert (table, IDL_NODE_UP (p), list_head);
+
+		return FALSE;
 	}
 
 	return TRUE;
 }
 
-void IDL_tree_remove_inhibits (IDL_tree *p, IDL_ns ns)
+void IDL_tree_remove_inhibits (IDL_tree *tree, IDL_ns ns)
 {
 	RemoveListNodeData data;
 	GHashTable *table = g_hash_table_new (g_direct_hash, g_direct_equal);
 	gint removed;
 
-	IDL_tree_walk_in_order (*p, (IDL_tree_func) load_inhibits, table);
+	g_return_if_fail (tree != NULL);
+	g_return_if_fail (ns != NULL);
+
+	IDL_tree_walk_in_order (*tree, (IDL_tree_func) load_inhibits, table);
 	removed = g_hash_table_size (table);
-	data.root = p;
+	data.root = tree;
 	data.removed_nodes = IDL_NS (ns).inhibits;
 	g_hash_table_foreach (table, (GHFunc) remove_list_node, &data);
 	g_hash_table_destroy (table);
