@@ -71,11 +71,8 @@ static void singleOptionHelp(FILE * f, int maxLeftCol,
     char format[10];
     char * left;
     const char * argDescrip = getArgDescrip(opt, translation_domain);
-#if defined(__STRICT_ANSI__) && defined(__GNUC__)
-    left = __builtin_alloca(maxLeftCol + 1);
-#else
-    left = alloca(maxLeftCol + 1);
-#endif
+
+    left = malloc(maxLeftCol + 1);
 
     *left = '\0';
     if (opt->longName && opt->shortName)
@@ -93,6 +90,7 @@ static void singleOptionHelp(FILE * f, int maxLeftCol,
     if (help)
 	fprintf(f,"  %-*s   ", maxLeftCol, left);
     else {
+	free(left);
 	fprintf(f,"  %s\n", left); 
 	return;
     }
@@ -113,6 +111,8 @@ static void singleOptionHelp(FILE * f, int maxLeftCol,
     }
 
     if (helpLength) fprintf(f, "%s\n", help);
+
+    free(left);
 }
 
 static int maxArgWidth(const struct poptOption * opt,
