@@ -46,7 +46,7 @@ int poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr) {
     strcpy(buf, s);
     bufStart = buf;
 
-    src = s;
+    src = (char *)s;
     dst = buf;
     argv[argc] = buf;
 
