@@ -401,7 +401,7 @@ iiop_connection_init(IIOPConnection *connection,
     GIOP_CONNECTION_IIOP;
 
   GIOP_CONNECTION(connection)->destroy_func =
-    (gpointer)iiop_connection_destroy;
+    (void (*)(GIOPConnection *))iiop_connection_destroy;
 
   connection->icnxtype = iioptype;
 }
@@ -422,7 +422,7 @@ iiop_connection_from_fd(int fd, IIOPConnection *parent)
 {
   IIOPConnection *fd_cnx;
   struct hostent *hent;
-  int n;
+  socklen_t n;
 
   g_assert(fd >= 0);
 
@@ -443,13 +443,15 @@ iiop_connection_from_fd(int fd, IIOPConnection *parent)
   case IIOP_USOCK:
     n = sizeof(struct sockaddr_un);
     fd_cnx->u.usock.sun_family = AF_UNIX;
-    getpeername(GIOP_CONNECTION_GET_FD(fd_cnx), &fd_cnx->u.usock, &n);
+    getpeername(GIOP_CONNECTION_GET_FD(fd_cnx),
+	(struct sockaddr *)&fd_cnx->u.usock, &n);
     break;
 
 #ifdef HAVE_IPV6
   case IIOP_IPV6:
     n = sizeof(struct sockaddr_in6);
-    getpeername(GIOP_CONNECTION_GET_FD(fd_cnx), &fd_cnx->u.ipv6.location, &n);
+    getpeername(GIOP_CONNECTION_GET_FD(fd_cnx),
+	(struct sockaddr *)&fd_cnx->u.ipv6.location, &n);
     hent = gethostbyaddr((const char *)&fd_cnx->u.ipv6.location.sin6_addr, 
 			 sizeof(fd_cnx->u.ipv6.location.sin6_addr), AF_INET6);
     fd_cnx->u.ipv6.hostname = g_strdup(hent->h_name);
@@ -486,7 +488,7 @@ iiop_connection_server(void)
 {
   struct hostent *hent, *hent2;
   char hn_tmp[65];
-  int n;
+  socklen_t n;
   IIOPConnection *server_cnx = g_new0(IIOPConnection, 1);
 
   iiop_connection_init(server_cnx, GIOP_CONNECTION_SERVER, IIOP_IPV4);
@@ -950,16 +952,17 @@ failed:
  *    Description: Performs accept(), TCP wrapper, access checking and related
  *                 duties on a connection
  */
+int allow_severity = LOG_INFO, deny_severity = LOG_NOTICE;
+
 #if defined(HAVE_HOSTS_ACCESS) && defined(HAVE_TCPD_H)
 DEFINE_LOCK(tcp_wrappers_usage);
 
-int allow_severity, deny_severity;
 #endif
 static void
 iiop_connection_server_accept(GIOPConnection *connection)
 {
   struct sockaddr sock;
-  int n;
+  socklen_t n;
   int newfd;
   GIOPConnection *newcnx;
 
@@ -1077,7 +1080,9 @@ void giop_main_quit(void) { giop_nloops--; }
 void
 giop_main(void)
 {
-  int looplevel = ++giop_nloops;
+  int looplevel;
+
+  looplevel = ++giop_nloops;
 
   while(giop_nloops > 0) {
 
