@@ -177,6 +177,17 @@ giop_send_buffer_write(GIOPSendBuffer *send_buffer)
   nvecs = GIOP_MESSAGE_BUFFER(send_buffer)->iovecs->len;
   curvec = (struct iovec *)GIOP_MESSAGE_BUFFER(send_buffer)->iovecs->data;
 
+#if defined(DEBUG) && 0
+  g_print("Message of length %d looks like:\n",
+	  GIOP_MESSAGE_BUFFER(send_buffer)->message_header.message_size);
+  for(sum = 0, i = 2; i < nvecs; i++) {
+
+    sum += curvec[i].iov_len;
+    g_print("    [%p, %d]: %d\n", curvec[i].iov_base, curvec[i].iov_len,
+	    sum);
+  }
+#endif
+
   res = writev(fd, curvec, nvecs);
 
   for(sum = res; sum < (GIOP_MESSAGE_BUFFER(send_buffer)->message_header.message_size + sizeof(GIOPMessageHeader)); ) {
@@ -184,11 +195,11 @@ giop_send_buffer_write(GIOPSendBuffer *send_buffer)
       giop_main_handle_connection_exception(cnx);
       return;
     }
-      
+
     for(i = t = 0; t < sum; i++)
       t += curvec[i].iov_len;
     curvec = &curvec[i-1];
-    ((char *)curvec->iov_base) += t - sum;
+    curvec->iov_base = ((guchar *)curvec->iov_base) + (t - sum);
     curvec->iov_len -= t - sum;
 
     nvecs -= i - 1;
@@ -300,8 +311,8 @@ giop_send_request_buffer_use(GIOPConnection *connection,
 
   ORBit_Trace(TraceMod_IIOP, TraceLevel_Debug,
 	      "Sending request %s id %d to %s\n",
-	      operation_vec->iov_base + 4,
-	      request_id, object_key_vec->iov_base + 4);
+	      ((guchar *)operation_vec->iov_base) + 4,
+	      request_id, ((guchar *)object_key_vec->iov_base) + 4);
 
   send_buffer = giop_send_buffer_use(connection);
 
@@ -312,7 +323,9 @@ giop_send_request_buffer_use(GIOPConnection *connection,
 
   response_expected = response_expected?1:0;
   API(&response_expected, 1);
+#if 0
   AP((gpointer)giop_scratch_space, 3);
+#endif
 
   giop_message_buffer_do_alignment(GIOP_MESSAGE_BUFFER(send_buffer),
 				   sizeof(CORBA_unsigned_long));
@@ -357,7 +370,7 @@ giop_send_locate_request_buffer_use(GIOPConnection *connection,
 
 	ORBit_Trace(TraceMod_IIOP, TraceLevel_Debug,
 		"Sending locate request id %d to %s\n",
-		request_id, object_key_vec->iov_base + 4);
+		request_id, ((guchar *)object_key_vec->iov_base) + 4);
 
 	send_buffer = giop_send_buffer_use(connection);
 
@@ -394,33 +407,36 @@ giop_message_buffer_do_alignment(GIOPMessageBuffer *buffer,
   struct iovec newvec;
   struct iovec *lastvec;
   guint alignme;
+  gulong real_msgsize;
+  gulong align_diff;
 
   if(align_for < 2) return 0;
   if(align_for >
      MAX(sizeof(GIOP_long_long),sizeof(GIOP_long_double)))
     align_for = MAX(sizeof(GIOP_long_long), sizeof(GIOP_long_double));
 
-  alignme = (gulong)ALIGN_ADDRESS(buffer->message_header.message_size, align_for);
+  real_msgsize = buffer->message_header.message_size+sizeof(GIOPMessageHeader);
 
-  if((alignme - buffer->message_header.message_size) > 0)
+  alignme = (gulong)ALIGN_ADDRESS(real_msgsize, align_for);
+
+  align_diff = alignme - real_msgsize;
+  if(align_diff > 0)
     {
       lastvec = (struct iovec *)(buffer->iovecs->data) 
 				 + buffer->iovecs->len - 1;
 
       if(lastvec->iov_base == giop_scratch_space)
 	{
-	  newvec.iov_len = alignme - buffer->message_header.message_size;
-	  lastvec->iov_len += newvec.iov_len;
-	  buffer->message_header.message_size =	alignme;
+	  newvec.iov_len = align_diff;
+	  lastvec->iov_len += align_diff;
+	  buffer->message_header.message_size += align_diff;
 	}
       else
 	{
 	  newvec.iov_base = (gpointer)giop_scratch_space;
-	  newvec.iov_len = alignme - buffer->message_header.message_size;
+	  newvec.iov_len = align_diff;
+	  buffer->message_header.message_size += align_diff;
 	  giop_message_buffer_append_iovec(buffer, &newvec);
-
-	  buffer->message_header.message_size +=
-	    newvec.iov_len;
 	}
       return newvec.iov_len;
     }
@@ -443,7 +459,7 @@ giop_message_buffer_append_mem_a(GIOPMessageBuffer *buffer,
 			     + buffer->iovecs->len - 1;
 
   if((mem_region == giop_scratch_space && lastvec->iov_base == giop_scratch_space)
-     || (alignfor == 0 && (lastvec->iov_base + lastvec->iov_len) == mem_region))
+     || (alignfor == 0 && (((guchar *)lastvec->iov_base) + lastvec->iov_len) == mem_region))
     {
       lastvec->iov_len += mem_region_length;
     }
@@ -470,7 +486,7 @@ giop_message_buffer_append_mem(GIOPMessageBuffer *buffer,
 
   if((mem_region == giop_scratch_space
       && lastvec->iov_base == giop_scratch_space)
-     || ((lastvec->iov_base + lastvec->iov_len) == mem_region))
+     || ((((guchar *)lastvec->iov_base) + lastvec->iov_len) == mem_region))
     {
       lastvec->iov_len += mem_region_length;
     }
@@ -510,7 +526,7 @@ giop_send_buffer_append_mem_indirect(GIOPSendBuffer *send_buffer,
     if((thisblock_size >= sizeof(CORBA_unsigned_long))
        || (mem_region_length - offset) < sizeof(CORBA_unsigned_long)) {
       if (!blockstart)
-	(guchar*)blockstart =
+	blockstart =
 	  ((guchar*) send_buffer->indirect) + send_buffer->indirect_used;
 
       memcpy((guchar*)send_buffer->indirect + send_buffer->indirect_used,
@@ -630,7 +646,14 @@ giop_recv_buffer_unuse(GIOPRecvBuffer *buffer)
 {
   g_return_if_fail(buffer != NULL);
 
-  g_free(buffer->message_body);
+  if(buffer->message_body) {
+    buffer->message_body = ((guchar *)buffer->message_body)
+      - sizeof(GIOPMessageHeader);
+    
+    g_free(buffer->message_body);
+    buffer->message_body = NULL;
+  }
+
   if(GIOP_MESSAGE_BUFFER(buffer)->connection->incoming_msg == buffer)
     GIOP_MESSAGE_BUFFER(buffer)->connection->incoming_msg = NULL;
 
@@ -683,7 +706,7 @@ giop_recv_message_buffer_use(GIOPConnection *connection)
   GIOPRecvBuffer *retval;
   char *bptr;
   int sysret;
-  int message_size;
+  guint message_size;
   
   if (!connection)
     return NULL;
@@ -707,7 +730,8 @@ giop_recv_message_buffer_use(GIOPConnection *connection)
 	- retval->left_to_read;
       break;
     case GIOP_MSG_READING_BODY:
-      bptr = retval->message_body;
+      bptr = retval->cur; /* Reason for not using retval->message_body:
+			     See note XXX1 below */
       bptr += GIOP_MESSAGE_BUFFER(retval)->message_header.message_size;
       bptr -= retval->left_to_read;
       break;
@@ -742,12 +766,12 @@ giop_recv_message_buffer_use(GIOPConnection *connection)
 
 	if(giop_msg_conversion_needed(GIOP_MESSAGE_BUFFER(retval))) {
 	  CORBA_unsigned_long t = GIOP_MESSAGE_BUFFER(retval)->message_header.message_size;
-	  retval->decoder = (gpointer)iiop_byteswap;
+	  retval->decoder = (void (*)(gpointer, gpointer, gulong))iiop_byteswap;
 
 	  iiop_byteswap((gpointer)&GIOP_MESSAGE_BUFFER(retval)->message_header.message_size,
 			(gpointer)&t, sizeof(t));
 	} else {
-	  retval->decoder = (gpointer)memcpy;
+	  retval->decoder = (void (*)(gpointer,gpointer,gulong))memcpy;
 	}
 
 	message_size = GIOP_MESSAGE_BUFFER(retval)->message_header.message_size;
@@ -757,12 +781,15 @@ giop_recv_message_buffer_use(GIOPConnection *connection)
 	  goto errout;
 	}
 
-	retval->message_body = g_malloc(message_size);
+	retval->message_body = g_malloc(message_size+sizeof(GIOPMessageHeader));
+	/* XXX1 This is a lame hack to work with the fact that
+	   alignment is relative to the MessageHeader, not the RequestHeader */
+	retval->message_body = ((guchar *)retval->message_body) + sizeof(GIOPMessageHeader);
+	retval->cur = retval->message_body;
 	retval->state = GIOP_MSG_READING_BODY;
 	retval->left_to_read = message_size;
 	break;
       case GIOP_MSG_READING_BODY:
-	retval->cur = retval->message_body;
 	if(giop_recv_decode_message(retval))
 	  goto errout;
 	connection->incoming_msg = NULL;
@@ -990,7 +1017,37 @@ giop_recv_decode_message(GIOPRecvBuffer *buf)
     }
 }
 
-# define CHECK_POS(buf) g_return_val_if_fail((guchar*)GIOP_RECV_BUFFER(buf)->cur <= (((guchar *)GIOP_RECV_BUFFER(buf)->message_body) + GIOP_MESSAGE_BUFFER(buf)->message_header.message_size), -1)
+/* if(currptr+len > end || currptr + len < currptr) */
+
+/* This whole mess needs redoing. */
+
+#define CHECK_NEW_POS(buf, requested_increment) \
+g_return_val_if_fail( (( ((guchar*)GIOP_RECV_BUFFER(buf)->cur) \
+		        + (requested_increment) ) \
+		       <= ( ((guchar *)GIOP_RECV_BUFFER(buf)->message_body) \
+			   + GIOP_MESSAGE_BUFFER(buf)->message_header.message_size)) \
+		      && ( ( ((guchar*)GIOP_RECV_BUFFER(buf)->cur) \
+			    + (requested_increment) ) \
+			  >= ((guchar*)GIOP_RECV_BUFFER(buf)->cur) ), -1)
+
+#define SAFE_ALIGN_ADDRESS(buf, amt) G_STMT_START { \
+guchar *newval; \
+newval = ALIGN_ADDRESS(GIOP_RECV_BUFFER(buf)->cur, amt); \
+CHECK_NEW_POS(buf, newval-((guchar *)GIOP_RECV_BUFFER(buf)->cur)); \
+GIOP_RECV_BUFFER(buf)->cur = newval; \
+} G_STMT_END
+
+#define GET_ULONG(x) G_STMT_START{					\
+                (x) = GUINT32_SWAP_LE_BE((*(CORBA_unsigned_long *)buf->cur)); \
+                CHECK_NEW_POS(buf, sizeof(CORBA_unsigned_long));        \
+		buf->cur = ((guchar *)buf->cur) + sizeof(CORBA_unsigned_long);	\
+	}G_STMT_END
+
+#define GET_ULONG_NC(x) G_STMT_START{ \
+			*(x) = (*((CORBA_unsigned_long *)(buf->cur))); \
+                        CHECK_NEW_POS(buf, sizeof(CORBA_unsigned_long)); \
+			buf->cur = ((guchar *)buf->cur) + sizeof(CORBA_unsigned_long); \
+		}G_STMT_END
 
 /* There be dragons in here. */
 static gint
@@ -1013,64 +1070,52 @@ giop_recv_reply_decode_message(GIOPRecvBuffer *buf)
   int i;
 
   buf->message.u.reply.service_context._maximum = 0;
-  CHECK_POS(buf);
   if(giop_msg_conversion_needed(GIOP_MESSAGE_BUFFER(buf))) 
     {
-
-#define GET_ULONG(x) G_STMT_START{					\
-		iiop_byteswap ((guchar *)&(x), 				\
-			       (guchar *)(buf->cur),			\
-			        sizeof(CORBA_unsigned_long)); 		\
-		(guchar*) buf->cur += sizeof(CORBA_unsigned_long);	\
-	}G_STMT_END
-
       GET_ULONG(buf->message.u.reply.service_context._length);
+/* XXX bad hardcoded hack until someone gives a "right answer" to how to
+solve this problem */
+      if(buf->message.u.reply.service_context._length > 128) return -1;
       buf->message.u.reply.service_context._buffer =
 	g_new(IOP_ServiceContext, buf->message.u.reply.service_context._length);
 
       for(i = 0; i < buf->message.u.reply.service_context._length; i++)
 	{
-	  CHECK_POS(buf);
-	  buf->cur = ALIGN_ADDRESS(buf->cur, 4);
+	  SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
 	  GET_ULONG(buf->message.u.reply.service_context._buffer[i].context_id);
 	  GET_ULONG(buf->message.u.reply.service_context._buffer[i].context_data._length);
 	  buf->message.u.reply.service_context._buffer[i].context_data._buffer =
 	    buf->cur;
-	  (guchar *) buf->cur += buf->message.u.reply.service_context._buffer[i].context_data._length;
+	  CHECK_NEW_POS(buf, buf->message.u.reply.service_context._buffer[i].context_data._length);
+	  buf->cur = ((guchar *)buf->cur) + buf->message.u.reply.service_context._buffer[i].context_data._length;
 	}
-      CHECK_POS(buf);
       GET_ULONG(buf->message.u.reply.request_id);
       GET_ULONG(buf->message.u.reply.reply_status);
     }
   else
     {
-#define GET_ULONG_NC(x) G_STMT_START{ \
-			*(x) = (*((CORBA_unsigned_long *)(buf->cur))); \
-			(guchar *)buf->cur += sizeof(CORBA_unsigned_long); \
-		}G_STMT_END
 
       GET_ULONG_NC(&buf->message.u.reply.service_context._length);
+/* XXX bad hardcoded hack until someone gives a "right answer" to how to
+solve this problem */
+      if(buf->message.u.reply.service_context._length > 128) return -1;
       buf->message.u.reply.service_context._buffer =
 	g_new(IOP_ServiceContext, buf->message.u.reply.service_context._length);
 
       for(i = 0; i < buf->message.u.reply.service_context._length; i++)
 	{
-	  CHECK_POS(buf);
-	  buf->cur = ALIGN_ADDRESS(buf->cur, 4);
+	  SAFE_ALIGN_ADDRESS(buf, sizeof(CORBA_unsigned_long));
 	  GET_ULONG_NC(&buf->message.u.reply.service_context._buffer[i].context_id);
 	  GET_ULONG_NC(&buf->message.u.reply.service_context._buffer[i].context_data._length);
 	  buf->message.u.reply.service_context._buffer[i].context_data._buffer =
 	    buf->cur;
-	  (guchar *) buf->cur += buf->message.u.reply.service_context._buffer[i].context_data._length;
+	  CHECK_NEW_POS(buf, buf->message.u.reply.service_context._buffer[i].context_data._length);
+	  buf->cur = ((guchar *)buf->cur) + buf->message.u.reply.service_context._buffer[i].context_data._length;
 	}
-      CHECK_POS(buf);
       GET_ULONG_NC(&buf->message.u.reply.request_id);
       GET_ULONG_NC(&buf->message.u.reply.reply_status);
     }
 
-#undef GET_ULONG  
-#undef GET_ULONG_NC
-
 #if 0
   g_message("[%d] Received reply %d size %d to request %d",
 	    getpid(),
@@ -1085,31 +1130,17 @@ giop_recv_reply_decode_message(GIOPRecvBuffer *buf)
 static gint
 giop_recv_locate_reply_decode_message(GIOPRecvBuffer *buf)
 {
-  CHECK_POS(buf);
   if(giop_msg_conversion_needed(GIOP_MESSAGE_BUFFER(buf))) 
     {
-
-#define GET_ULONG(x) G_STMT_START{ \
-			iiop_byteswap((guchar *)&(x),			\
-		          (guchar *)((buf->cur)),			\
-		          sizeof(CORBA_unsigned_long));			\
-		        (guchar *)buf->cur += sizeof(CORBA_unsigned_long); \
-		}G_STMT_END
-
       GET_ULONG(buf->message.u.locate_reply.request_id);
       GET_ULONG(buf->message.u.locate_reply.locate_status);
     }
   else
     {
-#define GET_ULONG_NC(x) G_STMT_START{ *(x) = (*((CORBA_unsigned_long *)(buf->cur))); (guchar*)buf->cur+=sizeof(CORBA_unsigned_long); }G_STMT_END
-
       GET_ULONG_NC(&buf->message.u.locate_reply.request_id);
       GET_ULONG_NC(&buf->message.u.locate_reply.locate_status);
     }
 
-#undef GET_ULONG  
-#undef GET_ULONG_NC
-
   return 0;
 }
 
@@ -1122,90 +1153,96 @@ giop_recv_request_decode_message(GIOPRecvBuffer *buf)
   buf->message.u.request.service_context._maximum = 0;
   if(giop_msg_conversion_needed(GIOP_MESSAGE_BUFFER(buf))) 
     {
-
-#define GET_ULONG(x) G_STMT_START{ iiop_byteswap((guchar *)&(x), \
-			      (guchar *)((buf->cur)),\
-			       sizeof(CORBA_unsigned_long)); \
-			      (guchar*) buf->cur +=sizeof(CORBA_unsigned_long); }G_STMT_END
-      CHECK_POS(buf);
       GET_ULONG(buf->message.u.request.service_context._length);
+
+      /* XXX bad hardcoded hack until someone gives a "right answer"
+	 to how to solve this problem */
+
+      if(buf->message.u.request.service_context._length > 128) return -1;
       buf->message.u.request.service_context._buffer =
 	g_new(IOP_ServiceContext, buf->message.u.request.service_context._length);
+
       for(i = 0; i < buf->message.u.request.service_context._length; i++)
 	{
-	  CHECK_POS(buf);
-	  buf->cur = ALIGN_ADDRESS(buf->cur, 4);
+	  SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
 	  GET_ULONG(buf->message.u.request.service_context._buffer[i].context_id);
 	  GET_ULONG(buf->message.u.request.service_context._buffer[i].context_data._length);
 	  buf->message.u.request.service_context._buffer[i].context_data._buffer =
 	    buf->cur;
-	  (guchar*)buf->cur += buf->message.u.request.service_context._buffer[i].context_data._length;
+	  CHECK_NEW_POS(buf, buf->message.u.request.service_context._buffer[i].context_data._length);
+	  buf->cur = ((guchar *)buf->cur) + buf->message.u.request.service_context._buffer[i].context_data._length;
 	}
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(buf->message.u.request.request_id);
       buf->message.u.request.response_expected = *((GIOP_boolean *)buf->cur);
-      (guchar*)buf->cur += sizeof(GIOP_boolean);
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      CHECK_NEW_POS(buf, sizeof(GIOP_boolean));
+      buf->cur = ((guchar *)buf->cur) + sizeof(GIOP_boolean);
+
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(buf->message.u.request.object_key._length);
       buf->message.u.request.object_key._buffer = buf->cur;
-      (guchar*)buf->cur += buf->message.u.request.object_key._length;
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+
+      CHECK_NEW_POS(buf, buf->message.u.request.object_key._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.request.object_key._length;
+
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(len);
       buf->message.u.request.operation = buf->cur;
-      (guchar*)buf->cur += len;
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+
+      CHECK_NEW_POS(buf, len);
+      buf->cur = ((guchar *)buf->cur) + len;
+
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(buf->message.u.request.requesting_principal._length);
-      buf->message.u.request.requesting_principal._buffer = buf->cur;      
-      (guchar*)buf->cur += buf->message.u.request.requesting_principal._length;
-      CHECK_POS(buf);
+      buf->message.u.request.requesting_principal._buffer = buf->cur;
+
+      CHECK_NEW_POS(buf, buf->message.u.request.requesting_principal._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.request.requesting_principal._length;
     }
   else
     {
-#define GET_ULONG_NC(x) G_STMT_START{ *(x) = (*((CORBA_unsigned_long *)(buf->cur))); (guchar*)buf->cur+=sizeof(CORBA_unsigned_long); }G_STMT_END
-
-      CHECK_POS(buf);
       GET_ULONG_NC(&buf->message.u.request.service_context._length);
+
+      /* XXX bad hardcoded hack until someone gives a "right answer"
+	 to how to solve this problem */
+      if(buf->message.u.request.service_context._length > 128) return -1;
       buf->message.u.request.service_context._buffer =
 	g_new(IOP_ServiceContext, buf->message.u.request.service_context._length);
 
       for(i = 0; i < buf->message.u.request.service_context._length; i++)
 	{
-	  CHECK_POS(buf);
-	  buf->cur = ALIGN_ADDRESS(buf->cur, 4);
+	  SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
 	  GET_ULONG_NC(&buf->message.u.request.service_context._buffer[i].context_id);
 	  GET_ULONG_NC(&buf->message.u.request.service_context._buffer[i].context_data._length);
 	  buf->message.u.request.service_context._buffer[i].context_data._buffer =
 	    buf->cur;
-	  (guchar*)buf->cur += buf->message.u.request.service_context._buffer[i].context_data._length;
+	  CHECK_NEW_POS(buf, buf->message.u.request.service_context._buffer[i].context_data._length);
+	  buf->cur = ((guchar *)buf->cur) + buf->message.u.request.service_context._buffer[i].context_data._length;
 	}
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG_NC(&buf->message.u.request.request_id);
       buf->message.u.request.response_expected = *((GIOP_boolean *)buf->cur);
-      (guchar*)buf->cur += sizeof(GIOP_boolean);
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      CHECK_NEW_POS(buf, sizeof(GIOP_boolean));
+      buf->cur = ((guchar *)buf->cur) + sizeof(GIOP_boolean);
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG_NC(&buf->message.u.request.object_key._length);
       buf->message.u.request.object_key._buffer = buf->cur;
-      (guchar*)buf->cur += buf->message.u.request.object_key._length;
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      CHECK_NEW_POS(buf, buf->message.u.request.object_key._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.request.object_key._length;
+
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG_NC(&len);
       buf->message.u.request.operation = buf->cur;
-      (guchar*)buf->cur += len;
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
-      GET_ULONG_NC(&buf->message.u.request.requesting_principal._length);
-      buf->message.u.request.requesting_principal._buffer = buf->cur;      
-      (guchar*)buf->cur += buf->message.u.request.requesting_principal._length;
-      CHECK_POS(buf);
-    }
+      CHECK_NEW_POS(buf, len);
+      buf->cur = ((guchar *)buf->cur) + len;
 
-#undef GET_ULONG  
-#undef GET_ULONG_NC
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
+      GET_ULONG_NC(&buf->message.u.request.requesting_principal._length);
+      buf->message.u.request.requesting_principal._buffer = buf->cur;
+      CHECK_NEW_POS(buf, buf->message.u.request.requesting_principal._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.request.requesting_principal._length;
+    }
 
 #if 0
   g_message("[%d] Received request %s size %d ID %d",
@@ -1223,39 +1260,25 @@ giop_recv_locate_request_decode_message(GIOPRecvBuffer *buf)
 {
   if(giop_msg_conversion_needed(GIOP_MESSAGE_BUFFER(buf))) 
     {
-
-#define GET_ULONG(x) G_STMT_START{ iiop_byteswap((guchar *)&(x), \
-			      (guchar *)((buf->cur)),\
-			       sizeof(CORBA_unsigned_long));\
-			       (guchar*)buf->cur +=sizeof(CORBA_unsigned_long); }G_STMT_END
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(buf->message.u.locate_request.request_id);
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG(buf->message.u.locate_request.object_key._length);
       buf->message.u.locate_request.object_key._buffer = buf->cur;
-      (guchar*)buf->cur += buf->message.u.locate_request.object_key._length;
-      CHECK_POS(buf);
+      CHECK_NEW_POS(buf, buf->message.u.locate_request.object_key._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.locate_request.object_key._length;
     }
   else
     {
-#define GET_ULONG_NC(x) G_STMT_START{ *(x) = (*((CORBA_unsigned_long *)(buf->cur))); (guchar*)buf->cur+=sizeof(CORBA_unsigned_long); }G_STMT_END
-
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG_NC(&buf->message.u.locate_request.request_id);
-      CHECK_POS(buf);
-      buf->cur = ALIGN_ADDRESS(buf->cur, sizeof(GIOP_unsigned_long));
+      SAFE_ALIGN_ADDRESS(buf, sizeof(GIOP_unsigned_long));
       GET_ULONG_NC(&buf->message.u.locate_request.object_key._length);
       buf->message.u.locate_request.object_key._buffer = buf->cur;
-      (guchar*)buf->cur += buf->message.u.locate_request.object_key._length;
-      CHECK_POS(buf);
+      CHECK_NEW_POS(buf, buf->message.u.locate_request.object_key._length);
+      buf->cur = ((guchar *)buf->cur) + buf->message.u.locate_request.object_key._length;
     }
 
-#undef GET_ULONG  
-#undef GET_ULONG_NC
-
   return 0;
 }
 
