@@ -23,8 +23,12 @@ orbit_IDL_tree_to_c(const char *base_filename, IDL_ns namespace, IDL_tree tree)
   GString *curfile_name = g_string_new(NULL);
   char *hdrname;
 
-  if(debuglevel >= 4)
-    orbit_cbe_print_node(tree, 0);
+  if(debuglevel >= IDL_WARNINGMAX) {
+    if (debuglevel == IDL_WARNINGMAX)
+      IDL_tree_to_IDL(tree, namespace, stdout, IDLF_OUTPUT_CODEFRAGS);
+    else
+      orbit_cbe_print_node(tree, 0);
+  }
   
   base_filename = g_basename(base_filename);
 
@@ -1087,7 +1091,7 @@ cbe_get_type_tail_alignment(IDL_tree typespec)
     return cbe_get_type_tail_alignment(cbe_get_typespec(IDL_TYPE_SEQUENCE(typespec).simple_type_spec));
     break;
   case IDLN_TYPE_ARRAY:
-    return cbe_get_type_tail_alignment(cbe_get_typespec(IDL_TYPE_ARRAY(typespec).ident));
+    return cbe_get_type_tail_alignment(cbe_get_typespec(IDL_NODE_UP(typespec)));
     break;
   case IDLN_EXCEPT_DCL:
   case IDLN_TYPE_STRUCT:
