@@ -501,7 +501,7 @@ static void cbe_output_demarshal_type_union(CBEDemarshalInfo *mi)
     cbe_output_demarshaller(&subdmi);
   }
   if(!subdmi.had_default)
-    fprintf(mi->of, "default:\n");
+    fprintf(mi->of, "default: break;\n");
   fprintf(mi->of, "}\n\n");
 
   /* There is no way we can know the exact alignment at compile time,
