@@ -66,6 +66,8 @@ static void cbe_hdr_do_unaryop(CBEHeaderInfo *hinfo);
 static void cbe_hdr_do_native(CBEHeaderInfo *hinfo);
 static void cbe_hdr_do_codefrag(CBEHeaderInfo *hinfo);
 
+static void cbe_hdr_interface_print_skel_extern(CBEHeaderInfo *hinfo);
+
 void
 orbit_cbe_write_header(FILE *outfile, IDL_ns ns, IDL_tree tree)
 {
@@ -470,8 +472,10 @@ cbe_hdr_do_except_dcl(CBEHeaderInfo *hinfo)
 			    "_", 0);
   fprintf(hinfo->of, "#ifndef _%s_defined\n"
 		     "#define _%s_defined\n\n", id, id);
+  fprintf(hinfo->of, "extern void _ORBIT_%s_demarshal(GIOPRecvBuffer *_ORBIT_recv_buffer, CORBA_Environment *ev);\n", id);
+  fprintf(hinfo->of, "extern void _ORBIT_%s_marshal(GIOPSendBuffer *_ORBIT_recv_buffer, CORBA_Environment *ev);\n", id);
   fprintf(hinfo->of, "typedef struct %s {\n", id);
-  
+
   if (IDL_EXCEPT_DCL(hinfo->tree).members) {
     for(curitem = IDL_EXCEPT_DCL(hinfo->tree).members; curitem;
         curitem = IDL_LIST(curitem).next) {
@@ -479,6 +483,7 @@ cbe_hdr_do_except_dcl(CBEHeaderInfo *hinfo)
       orbit_cbe_hdr_process_piece(&child_hinfo);
       fprintf(hinfo->of, "\n");
     }
+
   }
   else
     fprintf(hinfo->of, "	int empty_struct_member;\n");
@@ -597,6 +602,8 @@ cbe_hdr_do_op_dcl(CBEHeaderInfo *hinfo)
   g_assert(curitem);
   id2 = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(curitem).ident), "_", 0);
 
+  cbe_hdr_interface_print_skel_extern(hinfo);
+
   fprintf(hinfo->of, "extern ");
 
   orbit_cbe_write_typespec(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec);
@@ -605,7 +612,8 @@ cbe_hdr_do_op_dcl(CBEHeaderInfo *hinfo)
   fprintf(hinfo->of, " %s(%s _obj, ", id, id2);
 
   op = hinfo->tree;
-  for(curitem = IDL_OP_DCL(hinfo->tree).parameter_dcls; curitem; curitem = IDL_LIST(curitem).next) {
+  for(curitem = IDL_OP_DCL(op).parameter_dcls;
+      curitem; curitem = IDL_LIST(curitem).next) {
     hinfo->tree = IDL_LIST(curitem).data;
     orbit_cbe_hdr_process_piece(hinfo);
   }
@@ -625,7 +633,7 @@ static void
 cbe_hdr_do_inherited_op_dcl(CBEHeaderInfo *hinfo, IDL_tree current_interface)
 {
   char *id, *id2;
-  IDL_tree ident, curitem, intf;
+  IDL_tree ident, intf;
 
   if(!enable_inherited_ops)
     return;
@@ -635,18 +643,25 @@ cbe_hdr_do_inherited_op_dcl(CBEHeaderInfo *hinfo, IDL_tree current_interface)
   id2 = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(intf).ident),
 				"_", 0);
 
+  ident = IDL_OP_DCL(hinfo->tree).ident;
+  g_assert(ident);
+
+  fprintf(hinfo->of, "#define %s_%s %s_%s\n",
+	  id, IDL_IDENT(ident).str,
+	  id2, IDL_IDENT(ident).str);
+
+  g_free(id);
+  g_free(id2);
+
+#if 0
   fprintf(hinfo->of, "extern ");
 
   orbit_cbe_write_typespec(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec);
   orbit_cbe_param_printptrs(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec, DATA_RETURN);
 
-  ident = IDL_OP_DCL(hinfo->tree).ident;
-  g_assert(ident);
 
   fprintf(hinfo->of, " %s_%s(%s _obj, ",
 	  id, IDL_IDENT(ident).str, id);
-  g_free(id);
-  g_free(id2);
 
   for(curitem = IDL_OP_DCL(hinfo->tree).parameter_dcls; curitem; curitem = IDL_LIST(curitem).next) {
     hinfo->tree = IDL_LIST(curitem).data;
@@ -659,6 +674,7 @@ cbe_hdr_do_inherited_op_dcl(CBEHeaderInfo *hinfo, IDL_tree current_interface)
     fprintf(hinfo->of, "CORBA_Context ctx, ");
 
   fprintf(hinfo->of, "CORBA_Environment *ev);\n");
+#endif
 }
 
 static void
@@ -1020,7 +1036,6 @@ cbe_hdr_interface_print_epv_for_op(CBEHeaderInfo *hinfo)
 {
   /* hacked from cbe_hdr_do_op_dcl() */
   IDL_tree curitem;
-  
 
   fprintf(hinfo->of, "  ");
   orbit_cbe_write_typespec(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec);
@@ -1045,6 +1060,48 @@ cbe_hdr_interface_print_epv_for_op(CBEHeaderInfo *hinfo)
   fprintf(hinfo->of, "CORBA_Environment *ev);\n");
 }
 
+static void
+cbe_hdr_interface_print_skel_extern(CBEHeaderInfo *hinfo)
+{
+  CBEHeaderInfo subhinfo;
+  /* hacked from cbe_hdr_do_op_dcl() */
+  IDL_tree curitem;
+  char *id;
+
+  id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(IDL_NODE_UP(IDL_NODE_UP(hinfo->tree))).ident),
+			       "_", 0);
+
+  fprintf(hinfo->of,
+	  "extern void _ORBIT_skel_%s_%s(POA_%s *_ORBIT_servant, GIOPRecvBuffer *_ORBIT_recv_buffer, CORBA_Environment *ev, ",
+	  id,
+	  IDL_IDENT(IDL_OP_DCL(hinfo->tree).ident).str, id);
+
+  /* op = hinfo->tree; */
+  orbit_cbe_write_typespec(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec);
+  orbit_cbe_param_printptrs(hinfo->of, IDL_OP_DCL(hinfo->tree).op_type_spec, DATA_RETURN);
+
+  fprintf(hinfo->of, "(*_impl_%s)(PortableServer_Servant servant, ",
+	  IDL_IDENT(IDL_OP_DCL(hinfo->tree).ident).str);
+
+  subhinfo = *hinfo;
+  for(curitem = IDL_OP_DCL(hinfo->tree).parameter_dcls; curitem; curitem = IDL_LIST(curitem).next) {
+    subhinfo.tree = IDL_LIST(curitem).data;
+    orbit_cbe_hdr_process_piece(&subhinfo);
+  }
+
+  fprintf(hinfo->of, "CORBA_Environment *ev));\n");
+
+  g_free(id);
+
+#if 0
+  /* hinfo->tree.. see op saved above here... */
+  /* I'm unsure of how CORBA_Context should be used here... */
+  if(IDL_OP_DCL(hinfo->tree).context_expr)
+    fprintf(hinfo->of, "CORBA_Context ctx, ");
+#endif
+
+}
+
 static void
 cbe_hdr_interface_print_epv_for_attr(CBEHeaderInfo *hinfo)
 {
@@ -1163,6 +1220,32 @@ cbe_hdr_do_interface(CBEHeaderInfo *hinfo)
 
   fprintf(hinfo->of, "/* Begin interface %s */\n\n", id);
 
+  /* This is a quick-fix. It is really server side. Sue me :\ */
+  fprintf(hinfo->of, "  /* server-side (via the POA) data structures and methods */\n");
+  fprintf(hinfo->of, "#ifndef _POA_%s__vepv_defined\n"
+		     "#define _POA_%s__vepv_defined\n\n", id, id);
+  fprintf(hinfo->of, "typedef struct _POA_%s__epv POA_%s__epv;\n", id, id);
+
+  fprintf(hinfo->of, "typedef struct {\n");
+  fprintf(hinfo->of, "  PortableServer_ServantBase__epv* _base_epv;\n");
+  IDL_tree_traverse_parents(hinfo->tree, (GFunc)cbe_hdr_interface_print_vepv, hinfo->of);
+  fprintf(hinfo->of, "} POA_%s__vepv;\n", id);
+  fprintf(hinfo->of, "#endif /* !_POA_%s__vepv_defined */\n\n", id);
+
+  fprintf(hinfo->of, "#ifndef _POA_%s_defined\n"
+		     "#define _POA_%s_defined\n\n", id, id);
+  fprintf(hinfo->of, "typedef struct {\n");
+  fprintf(hinfo->of, "  void * _private;\n");
+  fprintf(hinfo->of, "  POA_%s__vepv* vepv;\n", id);
+  fprintf(hinfo->of, "} POA_%s;\n", id);
+  fprintf(hinfo->of, "#endif /* !_POA_%s_defined */\n\n", id);
+
+  fprintf(hinfo->of,
+	  "extern void POA_%s__init(POA_%s *servant, CORBA_Environment *ev);\n", id, id);
+  fprintf(hinfo->of,
+	  "extern void POA_%s__fini(POA_%s *servant, CORBA_Environment *ev);\n", id, id);
+
+
   fprintf(hinfo->of, "  /* client-side data structures and methods */\n");
   fprintf(hinfo->of, "#ifndef _%s_defined\n"
 		     "#define _%s_defined\n\n", id, id);
@@ -1183,36 +1266,14 @@ cbe_hdr_do_interface(CBEHeaderInfo *hinfo)
     fprintf(hinfo->of, "/* End inherited operations for %s */\n\n", id);
   }
 
-  fprintf(hinfo->of, "  /* server-side (via the POA) data structures and methods */\n");
   fprintf(hinfo->of, "#ifndef _POA_%s__epv_defined\n"
 		     "#define _POA_%s__epv_defined\n\n", id, id);
-  fprintf(hinfo->of, "typedef struct {\n");
+  fprintf(hinfo->of, "struct _POA_%s__epv {\n", id);
   fprintf(hinfo->of, "  void *_private;\n");
   cbe_hdr_interface_print_epv(hinfo);
-  fprintf(hinfo->of, "} POA_%s__epv;\n", id);
+  fprintf(hinfo->of, "};\n");
   fprintf(hinfo->of, "#endif /* !_POA_%s__epv_defined */\n\n", id);
 
-  fprintf(hinfo->of, "#ifndef _POA_%s__vepv_defined\n"
-		     "#define _POA_%s__vepv_defined\n\n", id, id);
-  fprintf(hinfo->of, "typedef struct {\n");
-  fprintf(hinfo->of, "  PortableServer_ServantBase__epv* _base_epv;\n");
-  IDL_tree_traverse_parents(hinfo->tree, (GFunc)cbe_hdr_interface_print_vepv, hinfo->of);
-  fprintf(hinfo->of, "} POA_%s__vepv;\n", id);
-  fprintf(hinfo->of, "#endif /* !_POA_%s__vepv_defined */\n\n", id);
-
-  fprintf(hinfo->of, "#ifndef _POA_%s_defined\n"
-		     "#define _POA_%s_defined\n\n", id, id);
-  fprintf(hinfo->of, "typedef struct {\n");
-  fprintf(hinfo->of, "  void * _private;\n");
-  fprintf(hinfo->of, "  POA_%s__vepv* vepv;\n", id);
-  fprintf(hinfo->of, "} POA_%s;\n", id);
-  fprintf(hinfo->of, "#endif /* !_POA_%s_defined */\n\n", id);
-
-  fprintf(hinfo->of,
-	  "extern void POA_%s__init(POA_%s *servant, CORBA_Environment *ev);\n", id, id);
-  fprintf(hinfo->of,
-	  "extern void POA_%s__fini(POA_%s *servant, CORBA_Environment *ev);\n", id, id);
-
   fprintf(hinfo->of, "/* End interface %s */\n", id);
     
   g_free(id);
