@@ -361,7 +361,7 @@ cbe_skel_do_except_dcl(CBESkelInfo *ski)
   id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_EXCEPT_DCL(ski->tree).ident),
 			       "_", 0);
 
-  fprintf(ski->of, "static void %s_marshal(GIOPSendBuffer *_ORBIT_send_buffer, CORBA_Environment *ev)\n", id);
+  fprintf(ski->of, "void _ORBIT_%s_marshal(GIOPSendBuffer *_ORBIT_send_buffer, CORBA_Environment *ev)\n", id);
 
   fprintf(ski->of, "{\n");
 
@@ -379,7 +379,6 @@ cbe_skel_do_except_dcl(CBESkelInfo *ski)
   g_free(id);
   g_string_free(tmpstr, TRUE);
 
-
   cbe_skel_do_type_struct(ski);
 }
 
@@ -631,7 +630,7 @@ cbe_skel_interface_print_relayers(const CBESkelInterfaceTraverseInfo *iti)
     } else {
        fprintf(iti->ski->of, "*impl = (gpointer)servant->vepv->%s_epv->%s;\n",
 	       opi->iface_id, opi->opname);
-       fprintf(iti->ski->of, "return (ORBitSkeleton)skel_%s_%s;\n",
+       fprintf(iti->ski->of, "return (ORBitSkeleton)_ORBIT_skel_%s_%s;\n",
 	       opi->iface_id, opi->opname);
     }
     fprintf(iti->ski->of, "break;\n");
@@ -930,7 +929,7 @@ cbe_skel_do_op_dcl_shared(CBESkelInfo *ski)
       IDL_tree curnode = IDL_LIST(curitem).data;
 
       id = orbit_cbe_get_typename(curnode);
-      fprintf(ski->of, "{(CORBA_TypeCode)&TC_%s_struct, (gpointer)%s_marshal},", id, id);
+      fprintf(ski->of, "{(CORBA_TypeCode)&TC_%s_struct, (gpointer)_ORBIT_%s_marshal},", id, id);
       g_free(id);
     }
     fprintf(ski->of, "{CORBA_OBJECT_NIL, NULL}};\n");
@@ -1006,7 +1005,7 @@ cbe_skel_do_op_dcl(CBESkelInfo *ski)
   g_assert(curitem);
   id2 = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(curitem).ident), "_", 0);
 
-  fprintf(ski->of, "\nstatic void\nskel_%s(POA_%s *_ORBIT_servant,\nGIOPRecvBuffer *_ORBIT_recv_buffer,\nCORBA_Environment *ev,\n", id, id2);
+  fprintf(ski->of, "\nvoid\n_ORBIT_skel_%s(POA_%s *_ORBIT_servant,\nGIOPRecvBuffer *_ORBIT_recv_buffer,\nCORBA_Environment *ev,\n", id, id2);
   g_free(id); g_free(id2);
 
   cbe_skel_do_op_dcl_shared(ski);
