@@ -142,7 +142,7 @@ static void cbe_ski_do_attr_dcl_internal(CBESkelImplInfo *ski, IDL_tree current_
 	    /* Output the operation on this attribute */
 	    g_string_sprintf(attrname, i ? "_set_%s" : "_get_%s",
 			     IDL_IDENT(IDL_LIST(curitem).data).str);
-	    ident = IDL_ident_new(strdup(attrname->str));
+	    ident = IDL_ident_new(g_strdup(attrname->str));
 	    
 	    /* Tell the ident where our namespace node is, and request a return value
 	       if this is the _get operation */
@@ -167,7 +167,7 @@ static void cbe_ski_do_attr_dcl_internal(CBESkelImplInfo *ski, IDL_tree current_
 		    IDL_OP_DCL(curop).parameter_dcls = IDL_list_new(
 			    IDL_param_dcl_new(IDL_PARAM_IN,
 					      IDL_ATTR_DCL(ski->tree).param_type_spec,
-					      IDL_ident_new(strdup("value"))));
+					      IDL_ident_new(g_strdup("value"))));
 	    }
 	    
 	    if(inherited==TRUE)
@@ -221,6 +221,7 @@ cbe_ski_do_op_dcl(CBESkelImplInfo *ski)
   switch(ski->pass) {
   case PASS_PROTOS:
   case PASS_IMPLSTUBS:
+    fprintf(ski->of, "static ");
     orbit_cbe_write_typespec(ski->of, IDL_OP_DCL(ski->tree).op_type_spec);
     orbit_cbe_param_printptrs(ski->of, IDL_OP_DCL(ski->tree).op_type_spec, DATA_RETURN);
     
@@ -231,7 +232,7 @@ cbe_ski_do_op_dcl(CBESkelImplInfo *ski)
     g_assert(curitem);
     id2 = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(curitem).ident), "_", 0);
     fprintf(ski->of, "\nimpl_%s(impl_POA_%s *servant,\n", id, id2);
-    free(id); free(id2);
+    g_free(id); g_free(id2);
     
     op = ski->tree;
     for(curitem = IDL_OP_DCL(ski->tree).parameter_dcls;
@@ -260,7 +261,7 @@ cbe_ski_do_op_dcl(CBESkelImplInfo *ski)
     id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_OP_DCL(ski->tree).ident),
 				 "_", 0);
     fprintf(ski->of, "(gpointer)&impl_%s,\n", id);
-    free(id);
+    g_free(id);
     break;
   default:
     break;
@@ -285,6 +286,7 @@ cbe_ski_do_inherited_op_dcl(CBESkelImplInfo *ski, IDL_tree current_interface)
   switch(ski->pass) {
   case PASS_PROTOS:
   case PASS_IMPLSTUBS:
+    fprintf(ski->of, "static ");
     orbit_cbe_write_typespec(ski->of, IDL_OP_DCL(ski->tree).op_type_spec);
     orbit_cbe_param_printptrs(ski->of, IDL_OP_DCL(ski->tree).op_type_spec, DATA_RETURN);
     
@@ -325,8 +327,8 @@ cbe_ski_do_inherited_op_dcl(CBESkelImplInfo *ski, IDL_tree current_interface)
     break;
   }
 
-  free(id);
-  free(id2);
+  g_free(id);
+  g_free(id2);
 }
 
 static void
@@ -358,7 +360,7 @@ cbe_ski_do_interface_vepv_entry(IDL_tree interface, CBESkelImplInfo *ski)
   if(interface==ski->tree) {
     id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(ski->tree).ident), "_", 0);
     fprintf(ski->of, "&impl_%s_epv,\n", id);
-    free(id);
+    g_free(id);
     return;
   }
 
@@ -370,8 +372,8 @@ cbe_ski_do_interface_vepv_entry(IDL_tree interface, CBESkelImplInfo *ski)
 			       "_", 0);
   fprintf(ski->of, "&impl_%s_%s_epv,\n", id, inherit_id);
 
-  free(id);
-  free(inherit_id);
+  g_free(id);
+  g_free(inherit_id);
 }
 
 static void
@@ -411,8 +413,8 @@ cbe_ski_do_inherited_methods(IDL_tree interface, CBESkelImplInfo *ski)
   if(ski->pass==PASS_EPVS) {
     fprintf(ski->of, "};");
 
-    free(id);
-    free(inherit_id);
+    g_free(id);
+    g_free(inherit_id);
   }
 }
 
@@ -438,7 +440,7 @@ cbe_ski_do_interface(CBESkelImplInfo *ski)
 	    "static PortableServer_ServantBase__epv impl_%s_base_epv = {\n",
 	    id);
     fprintf(ski->of, "NULL, /* _private data */\n");
-    fprintf(ski->of, "(gpointer)&impl_%s__destroy, /* finalize routine */\n", id);
+    fprintf(ski->of, "NULL, /* finalize routine */\n");
     fprintf(ski->of, "NULL, /* default_POA routine */\n");
     fprintf(ski->of, "};\n");
     fprintf(ski->of, "static POA_%s__epv impl_%s_epv = {\nNULL, /* _private */\n", id, id);
@@ -466,8 +468,11 @@ cbe_ski_do_interface(CBESkelImplInfo *ski)
     fprintf(ski->of, "CORBA_free(objid);\n");
     fprintf(ski->of, "retval = PortableServer_POA_servant_to_reference(poa, newservant, ev);\n");
     fprintf(ski->of, "\nreturn retval;\n}\n\n");
-    fprintf(ski->of, "/* You shouldn't call this routine directly without first deactivating the servant... */\n");
     fprintf(ski->of, "static void\nimpl_%s__destroy(impl_POA_%s *servant, CORBA_Environment *ev)\n{\n", id, id);
+    fprintf(ski->of, "PortableServer_ObjectId *objid;\n\n");
+    fprintf(ski->of, "objid = PortableServer_POA_servant_to_id(servant->poa, servant, ev);\n");
+    fprintf(ski->of, "PortableServer_POA_deactivate_object(servant->poa, objid, ev);\n");
+    fprintf(ski->of, "CORBA_free(objid);\n");
     fprintf(ski->of, "\nPOA_%s__fini((PortableServer_Servant)servant, ev);\n", id);
     fprintf(ski->of, "g_free(servant);\n}\n\n");
     subski.tree = IDL_INTERFACE(ski->tree).body;
@@ -486,5 +491,5 @@ cbe_ski_do_interface(CBESkelImplInfo *ski)
     break;
   }
 
-  free(id);
+  g_free(id);
 }
