@@ -357,7 +357,7 @@ cbe_stub_do_except_dcl(CBEStubInfo *sti)
   id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_EXCEPT_DCL(sti->tree).ident),
 			       "_", 0);
 
-  fprintf(sti->of, "static void %s_demarshal(GIOPRecvBuffer *_ORBIT_recv_buffer, CORBA_Environment *ev)\n", id);
+  fprintf(sti->of, "void _ORBIT_%s_demarshal(GIOPRecvBuffer *_ORBIT_recv_buffer, CORBA_Environment *ev)\n", id);
 
   fprintf(sti->of, "{\n");
 
@@ -802,7 +802,7 @@ cbe_stub_do_op_dcl_shared(CBEStubInfo *sti)
       IDL_tree curnode = IDL_LIST(curitem).data;
 
       id = orbit_cbe_get_typename(curnode);
-      fprintf(sti->of, "{(const CORBA_TypeCode)&TC_%s_struct, (gpointer)%s_demarshal},",
+      fprintf(sti->of, "{(const CORBA_TypeCode)&TC_%s_struct, (gpointer)_ORBIT_%s_demarshal},",
 	      id, id);
       g_free(id);
     }
@@ -953,6 +953,8 @@ cbe_stub_do_inherited_op_dcl(CBEStubInfo *sti, IDL_tree current_interface)
   char *id;
   IDL_tree ident;
 
+  return;
+
   id = IDL_ns_ident_to_qstring(IDL_IDENT_TO_NS(IDL_INTERFACE(current_interface).ident), "_", 0);
   ident = IDL_OP_DCL(sti->tree).ident;
   g_assert(ident);
