@@ -205,9 +205,23 @@ cbe_tc_generate(CBETCGenInfo *tci)
       g_assert(IDL_NODE_TYPE(IDL_LIST(curitem).data) == IDLN_MEMBER);
       for(curdcl = IDL_MEMBER(IDL_LIST(curitem).data).dcls; curdcl;
 	  curdcl = IDL_LIST(curdcl).next) {
-	g_assert(IDL_NODE_TYPE(IDL_LIST(curdcl).data) == IDLN_IDENT);
-	fprintf(tci->of, "\"%s\"",
-		IDL_IDENT(IDL_LIST(curdcl).data).str);
+	IDL_tree p = IDL_LIST(curdcl).data;
+
+	if (IDL_NODE_TYPE(p) != IDLN_IDENT) { /* FIXME */
+	  GString *s;
+	  s = IDL_tree_to_IDL_string (p, NULL, IDLF_OUTPUT_NO_NEWLINES);
+	  IDL_tree_error(p, "Type `%s' must be a previously declared typedef", s->str);
+	  IDL_tree_error(p, "(orbit-idl limitation; to be implemented)");
+	  g_string_free (s, TRUE);
+	  orbit_IDL_compile_failed(FALSE);
+	}
+
+	if (IDL_NODE_TYPE(p) == IDLN_IDENT)
+	  fprintf(tci->of, "\"%s\"", IDL_IDENT(p).str);
+	else
+	  fprintf(tci->of, "\"%s\"",
+		  IDL_IDENT(IDL_TYPE_ARRAY(p).ident).str);
+	
 	if(IDL_LIST(curdcl).next || IDL_LIST(curitem).next)
 	  fprintf(tci->of, ", ");
       }
@@ -225,11 +239,23 @@ cbe_tc_generate(CBETCGenInfo *tci)
 
       g_assert(IDL_NODE_TYPE(IDL_LIST(curitem).data) == IDLN_CASE_STMT);
 
-
       curdcl = IDL_CASE_STMT(IDL_LIST(curitem).data).element_spec;
       curdcl = IDL_LIST(IDL_MEMBER(curdcl).dcls).data;
-      g_assert(IDL_NODE_TYPE(curdcl) == IDLN_IDENT);
-      fprintf(tci->of, "\"%s\"", IDL_IDENT(curdcl).str);
+
+      if (IDL_NODE_TYPE(curdcl) != IDLN_IDENT) { /* FIXME */
+	GString *s;
+	s = IDL_tree_to_IDL_string (curdcl, NULL, IDLF_OUTPUT_NO_NEWLINES);
+	IDL_tree_error(curdcl, "Type `%s' must be a previously declared typedef", s->str);
+	IDL_tree_error(curdcl, "(orbit-idl limitation; to be implemented)");
+	g_string_free (s, TRUE);
+	orbit_IDL_compile_failed(FALSE);
+      }
+
+      if (IDL_NODE_TYPE(curdcl) == IDLN_IDENT)
+	fprintf(tci->of, "\"%s\"", IDL_IDENT(curdcl).str);
+      else
+	fprintf(tci->of, "\"%s\"",
+		IDL_IDENT(IDL_TYPE_ARRAY(curdcl).ident).str);
 
       if(IDL_LIST(curitem).next)
 	fprintf(tci->of, ", ");
@@ -363,7 +389,7 @@ cbe_tc_generate(CBETCGenInfo *tci)
 	  n++;
 	} else {
 	  /* default case */
-	  fprintf(tci->of, "{&TC_CORBA_octet_struct, &zero_int, CORBA_FALSE}");
+	  fprintf(tci->of, "{(CORBA_TypeCode)&TC_CORBA_octet_struct, (int *)&zero_int, CORBA_FALSE}");
 	}
 
 	if(IDL_LIST(curlabel).next || IDL_LIST(curitem).next)
