@@ -19,8 +19,8 @@ GMemChunk *x##_allocator = NULL
 #elif defined(ALLOCATOR_INITIALIZATION)
 
 #define ORBIT_DEFINE_CHUNK(x, xsize) INIT_LOCK(x##_allocator); \
-x##_allocator = g_mem_chunk_new(#x, xsize, \
-xsize * ORBIT_CHUNKS_PREALLOC, G_ALLOC_AND_FREE)
+x##_allocator = g_mem_chunk_new(#x, (xsize), \
+(xsize) * ORBIT_CHUNKS_PREALLOC, G_ALLOC_AND_FREE)
 
 #else
 
