@@ -133,7 +133,9 @@ ORBit_free(gpointer mem, CORBA_boolean free_strings)
 			x = block->free(x, my_data, free_strings);
 
 		if((gpointer)block->free == (gpointer)ORBit_free_via_TypeCode)
-			((guchar *)block) -= sizeof(CORBA_TypeCode);
+			/* ((guchar *)block) -= sizeof(CORBA_TypeCode); */
+			block = (ORBit_mem_info *)
+				(((guchar *)block) - sizeof(CORBA_TypeCode));
 		g_free(block);
 	} else
 		g_free(block);
@@ -186,7 +188,7 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		break;
 	case CORBA_tk_union:
 		subtc = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)ORBit_get_union_tag(tc, mem), NULL);
-		(guchar *) mem += ORBit_gather_alloc_info(tc->discriminator);
+		mem = ((guchar *)mem) + ORBit_gather_alloc_info(tc->discriminator);
 		n = 1;
 		for(i = 0; i < tc->sub_parts; i++) {
 			n = MAX(n, ORBit_find_alignment(tc->subtypes[i]));
