@@ -47,6 +47,7 @@ typedef struct {
 #define HEXOCTET(a,b) ((HEXDIGIT((a)) << 4) | HEXDIGIT((b)))
 
 extern CDR_Codec *CDR_codec_init(void);
+extern CDR_Codec *CDR_codec_init_static(CDR_Codec *codec);
 extern void CDR_codec_free(CDR_Codec *);
 
 extern void CDR_put_short(CDR_Codec *codec, CORBA_short s);
@@ -70,6 +71,7 @@ extern CORBA_boolean CDR_get_ushort(CDR_Codec *codec, CORBA_unsigned_short *us);
 extern CORBA_boolean CDR_get_ulong(CDR_Codec *codec, CORBA_unsigned_long *ul);
 extern CORBA_boolean CDR_get_octet(CDR_Codec *codec, CORBA_octet *datum);
 extern CORBA_boolean CDR_get_string(CDR_Codec *codec, CORBA_char **str);
+extern CORBA_boolean CDR_get_string_static(CDR_Codec *codec, CORBA_char **str);
 extern CORBA_boolean CDR_get_seq_begin(CDR_Codec *codec, CORBA_unsigned_long *ul);
 
 #endif /* !_ORBIT_CDR_H_ */
