@@ -27,13 +27,16 @@
 #define _ORBIT_CORBA_BASIC_SEQUENCES_TYPE_H_
 
 #include <ORBitutil/basic_types.h>
+#include <orb/corba_sequences.h>
 
-struct CORBA_sequence_octet {
-	unsigned long int _maximum;
-	unsigned long int _length;
+#ifndef _CORBA_sequence_octet_defined
+#define _CORBA_sequence_octet_defined 1
+struct CORBA_sequence_octet_struct {
+	CORBA_unsigned_long _maximum;
+	CORBA_unsigned_long _length;
 	CORBA_octet *_buffer;
-	unsigned int _flags;
+	CORBA_boolean _release;
 };
-
+#endif /* !_CORBA_sequence_octet_defined */
 
 #endif /* !_ORBIT_CORBA_BASIC_SEQUENCES_TYPE_H_ */
