@@ -41,9 +41,9 @@
 static void ORBit_object_try_existing_connections(CORBA_Object obj);
 static void CORBA_Object_release_fn(CORBA_Object obj, CORBA_Environment *ev);
 
-ORBit_RootObject_Interface CORBA_Object_epv =
+static ORBit_RootObject_Interface CORBA_Object_epv =
 {
-	(gpointer)CORBA_Object_release_fn,
+	(void (*)(gpointer, CORBA_Environment *))CORBA_Object_release_fn,
 };
 
 void ORBit_pseudo_object_init(ORBit_PseudoObject obj,
@@ -57,7 +57,7 @@ void ORBit_pseudo_object_init(ORBit_PseudoObject obj,
 
 static const ORBit_RootObject_Interface CORBA_Policy__epv =
 {
-	(gpointer)CORBA_Policy_destroy
+	(void (*)(gpointer, CORBA_Environment *))CORBA_Policy_destroy
 };
 
 void ORBit_policy_object_init(CORBA_Policy obj,
@@ -76,13 +76,11 @@ void ORBit_policy_object_init(CORBA_Policy obj,
 
 void ORBit_object_reference_init(CORBA_Object obj, CORBA_Environment *ev)
 {
-	ORBIT_ROOT_OBJECT(obj)->is_pseudo_object = FALSE;
-	ORBIT_ROOT_OBJECT(obj)->refs = 0;
 	/* set the interface up */
 	ORBit_RootObject_set_interface(ORBIT_ROOT_OBJECT(obj),&CORBA_Object_epv,ev);
 	/* initialise the reference count */
 	ORBIT_ROOT_OBJECT(obj)->refs = 0; 
-       
+	ORBIT_ROOT_OBJECT(obj)->is_pseudo_object = FALSE;
 }
 
 CORBA_Object 
@@ -177,7 +175,9 @@ ORBit_RootObject_set_interface(ORBit_RootObject obj,
 	obj->interface = epv;
 }
 
-#define GET_ATOM(x) G_STMT_START{ GIOP_RECV_BUFFER(recv_buffer)->decoder(&x, (GIOP_RECV_BUFFER(recv_buffer)->cur), sizeof(x)); ((guchar *)GIOP_RECV_BUFFER(recv_buffer)->cur) += sizeof(x); }G_STMT_END
+#define GET_ATOM(x) G_STMT_START{ GIOP_RECV_BUFFER(recv_buffer)->decoder(&x, (GIOP_RECV_BUFFER(recv_buffer)->cur), sizeof(x)); \
+GIOP_RECV_BUFFER(recv_buffer)->cur = ((guchar *)GIOP_RECV_BUFFER(recv_buffer)->cur) + sizeof(x); \
+}G_STMT_END
 #define ALIGNFOR(x) recv_buffer->cur = ALIGN_ADDRESS(recv_buffer->cur, sizeof(x))
 
 CORBA_Object
@@ -244,7 +244,7 @@ ORBit_demarshal_profile(GIOPRecvBuffer *recv_buffer, IOP_ProfileId profile_id)
 		CDR_codec_init_static(codec);
 		codec->buffer = recv_buffer->cur;
 		codec->release_buffer = CORBA_FALSE;
-		((guchar *)recv_buffer->cur) += subpart_len;
+		recv_buffer->cur = ((guchar *)recv_buffer->cur) + subpart_len;
 
 		codec->readonly = CORBA_TRUE;
 		codec->host_endian = codec->data_endian = FLAG_ENDIANNESS;
@@ -278,10 +278,11 @@ ORBit_demarshal_profile(GIOPRecvBuffer *recv_buffer, IOP_ProfileId profile_id)
 		break;
 
 	case IOP_TAG_MULTIPLE_COMPONENTS:
+	default:
 		GET_ATOM(subpart_len);
 		g_warning("IOP_TAG_MULTIPLE_COMPONENTS decoding needs finishing");
 		object_info->profile_type = IOP_TAG_MULTIPLE_COMPONENTS;
-		((guchar *)recv_buffer->cur) += subpart_len;
+		recv_buffer->cur = ((guchar *)recv_buffer->cur) + subpart_len;
 		return(object_info);
 		break;
 
@@ -290,7 +291,7 @@ ORBit_demarshal_profile(GIOPRecvBuffer *recv_buffer, IOP_ProfileId profile_id)
 		CDR_codec_init_static(codec);
 		codec->buffer = recv_buffer->cur;
 		codec->release_buffer = CORBA_FALSE;
-		((guchar *)recv_buffer->cur) += subpart_len;
+		recv_buffer->cur = ((guchar *)recv_buffer->cur) + subpart_len;
 
 		codec->readonly = CORBA_TRUE;
 		codec->host_endian = codec->data_endian = FLAG_ENDIANNESS;
@@ -346,7 +347,7 @@ GSList *ORBit_demarshal_IOR(GIOPRecvBuffer *recv_buffer)
 	if(len == 0)
 		return(NULL);
 
-	((guchar *)recv_buffer->cur) += len;
+	recv_buffer->cur = ((guchar *)recv_buffer->cur) + len;
 
 	/* Decode the sequence<TaggedProfile> */
 	ALIGNFOR(CORBA_unsigned_long);
@@ -387,27 +388,27 @@ ORBit_demarshal_object(GIOPRecvBuffer *recv_buffer, CORBA_ORB orb)
 	ALIGNFOR(CORBA_unsigned_long);
 	GET_ATOM(len);
 
-	if(len == 0)
-		return CORBA_OBJECT_NIL;
-
 	type_id = recv_buffer->cur;
-	((guchar *)recv_buffer->cur) += len;
+	recv_buffer->cur = ((guchar *)recv_buffer->cur) + len;
 
 	/* Decode the sequence<TaggedProfile> */
 	ALIGNFOR(CORBA_unsigned_long);
 	GET_ATOM(seq_len);
+
+	if(!seq_len)
+		return CORBA_OBJECT_NIL;
+
 	for(i = 0; i < seq_len; i++) {
 		ALIGNFOR(CORBA_unsigned_long);
 		GET_ATOM(profile_id);
 		object_info=ORBit_demarshal_profile(recv_buffer, profile_id);
-		if(object_info==NULL) {
-			g_warning("Doing an error exit because demarshal_profile failed");
-			goto error_exit;
-		} else {
+		if(object_info)
 			profiles=g_slist_append(profiles, object_info);
-		}
 	}
 
+	if(!profiles)
+		goto error_exit;
+
 	retval = ORBit_create_object_with_info(profiles, type_id, orb, &ev);
 
 	return retval;
@@ -428,7 +429,7 @@ static void ORBit_marshal_profile(gpointer item, gpointer data)
 	CDR_Codec codec_d;
 	CDR_Codec *codec = &codec_d;
 	CORBA_unsigned_long len;
-	char codecbuf[2048];
+	CORBA_octet codecbuf[2048];
 	static const CORBA_octet oc_endian = FLAG_ENDIANNESS;
 	static const CORBA_octet iiopversion[] = {1,0};
 
@@ -490,9 +491,16 @@ ORBit_marshal_object(GIOPSendBuffer *send_buffer, CORBA_Object obj)
 	CORBA_unsigned_long len;
 
 	if(!obj) {
-		len = 0;
-		giop_send_buffer_append_mem_indirect_a(send_buffer, &len,
-						       sizeof(len));
+		static const CORBA_unsigned_long zero = 0, one = 1;
+		/* zero-length typename */
+		giop_message_buffer_append_mem_a(GIOP_MESSAGE_BUFFER(send_buffer),
+						 &one, sizeof(one));
+		giop_message_buffer_append_mem(GIOP_MESSAGE_BUFFER(send_buffer),
+					       &zero, 1);
+
+		/* zero profiles */
+		giop_message_buffer_append_mem_a(GIOP_MESSAGE_BUFFER(send_buffer),
+						 &zero, sizeof(zero));
 		return;
 	}
 
