@@ -56,12 +56,12 @@ ORBit_POA_ServantManager_unuse_servant(PortableServer_Servant servant,
 
 static const ORBit_RootObject_Interface CORBA_POAManager_epv =
 {
-	(gpointer)ORBit_POAManager_release,
+	(void (*)(gpointer, CORBA_Environment *))ORBit_POAManager_release,
 };
 
 static const ORBit_RootObject_Interface CORBA_POA_epv =
 {
-	(gpointer)ORBit_POA_release,
+	(void (*)(gpointer, CORBA_Environment *))ORBit_POA_release,
 };
 
 guint
@@ -534,7 +534,7 @@ ORBit_POA_allocate_oid(PortableServer_POA poa,
 	new_objid->_length = len;
 	new_objid->_release = CORBA_TRUE;
 
-	strcpy(new_objid->_buffer, buf);
+	strcpy((CORBA_char *)new_objid->_buffer, buf);
 
 	return new_objid;
 }
