@@ -1022,7 +1022,8 @@ PortableServer_ObjectId *PortableServer_Current_get_object_id(PortableServer_Cur
 
 CORBA_char *PortableServer_ObjectId_to_string(PortableServer_ObjectId *id, CORBA_Environment *env)
 {
-	return CORBA_string_dup(id->_buffer);
+	g_warning("PortableServer_ObjectId_to_string - FIXME");
+	return CORBA_string_dup((CORBA_char *)id->_buffer);
 }
 
 CORBA_wchar *PortableServer_ObjectId_to_wstring(PortableServer_ObjectId *id, CORBA_Environment *env)
@@ -1294,7 +1295,7 @@ dynamic_impl_get_skel(PortableServer_DynamicImpl * servant,
 		      GIOPRecvBuffer * _ORBIT_recv_buffer,
 		      gpointer * impl)
 {
-	*impl = servant->vepv->PortableServer_DynamicImpl_epv->invoke;
+	*impl = (gpointer)servant->vepv->PortableServer_DynamicImpl_epv->invoke;
 
 	return (ORBitSkeleton)dynamic_impl_skel;
 }
@@ -1304,7 +1305,8 @@ PortableServer_DynamicImpl__init(PortableServer_Servant servant,
 				 CORBA_Environment *ev)
 {
 	static const PortableServer_ClassInfo class_info =
-	{(gpointer) &dynamic_impl_get_skel, "IDL:CORBA/Object:1.0", NULL};
+	{(ORBitSkeleton (*)(PortableServer_ServantBase *, gpointer, gpointer *))
+	 &dynamic_impl_get_skel, "IDL:CORBA/Object:1.0", NULL};
 	
 	PortableServer_ServantBase__init(servant, ev);
 	
