@@ -9,7 +9,7 @@ gpointer CORBA_sequence_octet_free(gpointer mem,
   if(seqo->_release)
     CORBA_free(seqo->_buffer);
 
-  return mem + sizeof(CORBA_sequence_octet);
+  return (gpointer)((guchar *)mem + sizeof(CORBA_sequence_octet));
 }
 
 CORBA_octet *
