@@ -33,7 +33,7 @@ main (int argc, char *argv[])
   any_value.long_value = 42;
   any_value.string_value = "fourty two.";
 
-  any._type = TC_TestAnyStruct;
+  any._type = (CORBA_TypeCode)TC_TestAnyStruct;
   any._value = &any_value;
   CORBA_any_set_release(&any, CORBA_FALSE );
   retany = TestAny_print (obj, &any, &ev);
